@@ -10,18 +10,20 @@ create.bspline.basis <- function (rangeval=c(0,1), nbasis=NULL, norder=4,
 #  NBASIS   ... the number of basis functions
 #  NORDER   ... order of b-splines (one higher than their degree).  The
 #                 default of 4 gives cubic splines.
-#  BREAKS   ... also called knots, these are a strictly increasing sequence
+#  BREAKS   ... also called knots, these are a strictly increasing sequence 
 #               of junction points between piecewise polynomial segments.
 #               They must satisfy BREAKS[1] = RANGEVAL[1] and
 #               BREAKS[NBREAKS] = RANGEVAL[2], where NBREAKS is the total
-#               number of BREAKS.  There must be at least 3 BREAKS.
-#  There is a potential for inconsistency among arguments NBASIS, NORDER, and
-#  BREAKS.  It is resolved as follows:
+#               number of BREAKS.  There must be at least 2 BREAKS.
+#  There is a potential for inconsistency among arguments NBASIS, NORDER,
+#  and BREAKS.  It is resolved as follows:
 #     If BREAKS is supplied, NBREAKS = length(BREAKS), and
 #     NBASIS = NBREAKS + NORDER - 2, no matter what value for NBASIS is
 #     supplied.
-#     If BREAKS is not supplied but NBASIS is, NBREAKS = NBASIS - NORDER + 2,
-#        and if this turns out to be less than 3, an error message results.
+#     If BREAKS is not supplied but NBASIS is,
+#               NBREAKS = NBASIS - NORDER + 2, 
+#               and if this turns out to be less than 2,
+#               an error message results.
 #     If neither BREAKS nor NBASIS is supplied, NBREAKS is set to 21.
 #  DROPIND  ... A vector of integers specificying the basis functions to
 #               be dropped, if any.  For example, if it is required that
@@ -43,35 +45,59 @@ create.bspline.basis <- function (rangeval=c(0,1), nbasis=NULL, norder=4,
 #  Returns
 #  BASISFD  ... a functional data basis object
 
-# Last modified 3 March 2007 by Spencer Graves
-#  Last modified 20 November 2005
+# Last modified 2007.09.07 by Spencer Graves
+# Previously modified 20 November 2005
 
   type <- "bspline"
 
 #  check RANGE
 
   if (length(rangeval) == 1){
-    if(rangeval <= 0) stop("RANGEVAL a single value that is not positive.")
+    if(rangeval <= 0)
+      stop("'rangeval' a single value that is not positive.")
     rangeval = c(0,rangeval)
   }
-  if (!rangechk(rangeval)) stop("Argument RANGEVAL is not correct.")
-
+  
+#  if (!rangechk(rangeval)) stop("Argument 'rangeval' is not correct.")
+  if(!is.vector(rangeval))
+    stop('rangeval is not a vector;  class(rangeval) = ', class(rangeval))
+# rangeval too long ??? 
+  if(length(rangeval)>2){
+    if(!is.null(breaks))
+      stop('length(rangeval)>2 and breaks can not both be provided; ',
+           ' length(rangeval) = ', length(rangeval),
+           ' and length(breaks) = ', length(breaks))
+    if(!is.null(nbasis))
+      stop('length(rangeval)>2 and nbasis can not both be provided; ',
+           ' length(rangeval) = ', length(rangeval),
+           ' and nbasis = ', nbasis)
+    breaks <- rangeval
+    rangeval <- range(breaks)
+  }
+  if(rangeval[1]>=rangeval[2])
+    stop('rangeval[1] must be less than rangeval[2];  instead ',
+         'rangeval[1] = ', rangeval[1], c('==', '>')[diff(rangeval)<0],
+         ' rangeval[2] = ', rangeval[2]) 
 #  check NORDER
 
-  if (!is.numeric(norder) || norder<=0) stop("norder must be positive integer")
-  norder <- ceiling(norder)
+  if(!is.numeric(norder) || (norder<=0) || ((norder%%1) > 0) ) 
+    stop("norder must be positive integer")
+#  norder <- ceiling(norder)
 
 #  check for various argument configurations
 
 # case of complete argument
-  if (!is.null(nbasis) & !is.null(breaks)) {
-    nbreaks <- length(breaks)
-    if(!is.numeric(nbasis) || nbasis<=0)
-      stop("Argument nbasis is not correct")
-    else nbasis <- ceiling(nbasis)
+  if (!is.null(nbasis)){
+    if((lnb <- length(nbasis))>1)
+      stop("length(nbasis) = ", lnb, " > 1;  first 2 elements = ",
+           nbasis[1], ", ", nbasis[2])
+    if(!is.null(breaks)) {
+      nbreaks <- length(breaks)
+      if(!is.numeric(nbasis) || nbasis<=0)
+        stop("Argument nbasis is not correct")
+      else nbasis <- ceiling(nbasis)
+    }
   }
-
-
 # case of NULL NBASIS
 
   if (is.null(nbasis) && !is.null(breaks)) {
@@ -82,8 +108,9 @@ create.bspline.basis <- function (rangeval=c(0,1), nbasis=NULL, norder=4,
 
 # case of NULL BREAKS
 
-  if (!(is.null(nbasis)) && is.null(breaks)) {
-    if(!is.numeric(nbasis) || nbasis<=0) stop("Argument nbasis is not correct")
+  if ((!is.null(nbasis)) && is.null(breaks)) {
+    if(!is.numeric(nbasis) || (nbasis<=0))
+      stop("Argument nbasis is not correct")
     else nbasis <- ceiling(nbasis)
     nbreaks <- nbasis - norder + 2
     if (nbreaks < 2) stop("Number of knots is less than 2")
@@ -105,10 +132,14 @@ create.bspline.basis <- function (rangeval=c(0,1), nbasis=NULL, norder=4,
 #  check BREAKS
 
   breaks <- sort(breaks)
-  if (breaks[1] != rangeval[1]) stop(
-              "Smallest value in BREAKS not equal to RANGEVAL[1].")
-  if (breaks[nbreaks] != rangeval[2])   stop(
-              "Largest  value in BREAKS not equal to RANGEVAL[2].")
+  if (breaks[1] != rangeval[1])
+    stop("Smallest value in breaks not equal to rangeval[1]; ",
+         " breaks[1] = ", breaks[1], " != rangeval[1] = ",
+         rangeval[1])
+  if (breaks[nbreaks] != rangeval[2])
+    stop("Largest  value in breaks not equal to rangeval[2]; ",
+         " breaks[nbreaks] = ", breaks[nbreaks],
+         " != rangeval[2] = ", rangeval[2])
   if (min(diff(breaks)) < 0) stop(
               "Values in BREAKS not increasing")
 
@@ -118,7 +149,7 @@ create.bspline.basis <- function (rangeval=c(0,1), nbasis=NULL, norder=4,
   if (nbreaks > 2) {
     params <- breaks[2:(nbreaks-1)]
   } else {
-    params <- NULL
+    params <- numeric(0)
   }
 
 #  check DROPIND
