@@ -8,7 +8,7 @@
 
 #  Generator function of class fdPar
 
-fdPar <- function(fdobj=fd(), Lfdobj=int2Lfd(0), lambda=0, estimate=TRUE, 
+fdPar <- function(fdobj=NULL, Lfdobj=NULL, lambda=0, estimate=TRUE, 
                   penmat=NULL){
 		
 # Sets up a functional parameter object
@@ -68,15 +68,30 @@ fdPar <- function(fdobj=fd(), Lfdobj=int2Lfd(0), lambda=0, estimate=TRUE,
       dropind  <- basisobj$dropind
       nbasis   <- nbasis - length(dropind)
     }
-    else stop("First argument is neither a functional data object nor a basis object.")
+    else if(is.numeric(fdobj)){
+      fdobj <- fd(fdobj)
+      nbasis <- fdobj$nbasis
+    }
+    else 
+      stop("First argument is neither a functional data object, ",
+           "nor a basis object, nor a parameter object, nor ",
+           "a matrix.")
   }
 
 #  check Lfdobj
-
-  Lfdobj <- int2Lfd(Lfdobj)
-
+  {
+    if(is.null(Lfdobj)){
+      norder <- {
+        if(fdobj$basis$type=='bspline')norder.bspline(fdobj$basis)
+        else 2
+      }
+      Lfdobj <- int2Lfd(max(0, norder-2))
+    }
+    else
+      Lfdobj <- int2Lfd(Lfdobj)
+  }
   if (!inherits(Lfdobj, "Lfd"))
-    stop("LFDOBJ is not a linear differential operator object.")
+    stop("'Lfdobj' is not a linear differential operator object.")
 
 #  check lambda
 
