@@ -1,5 +1,5 @@
 lambda2gcv <- function(log10lambda, argvals, y, fdParobj,
-                       wtvec=rep(1,length(y)), dffactor=1)
+                       wtvec=rep(1,length(y)))
 {
 #  LAMBDA2GCV smooths data using smooth_basis and returns the
 #  GCV criterion that results.  DFFACTOR is an optional multiplier of df
@@ -7,7 +7,8 @@ lambda2gcv <- function(log10lambda, argvals, y, fdParobj,
 
 fdParobj$lambda = 10^log10lambda
 
-smoothlist <- smooth.basis(argvals, y, fdParobj, wtvec, dffactor)
+#smoothlist <- smooth.basis(argvals, y, fdParobj, wtvec, dffactor)
+smoothlist <- smooth.basis(argvals, y, fdParobj, wtvec)
 
 gcv <- smoothlist$gcv
 
