@@ -9,6 +9,7 @@
 #  These analyses are intended to illustrate the analysis of nonperiod data
 #  where a spline basis is the logical choice.  These analyses complement
 #  the daily weather data in that sense.
+#
 #  The growth data have the additional feature of being essentially
 #  monotonic or, to say the same thing in another way, have an essentially
 #  positive first derivative or velocity.  This requires monotone smoothing.
@@ -16,10 +17,12 @@
 #  inspecting the acceleration of the height curves, so that great emphasis
 #  is placed here on getting a good sensible and stable acceleration
 #  estimate.
-#  Finally, a large prortion of the variation in the growth curve data is due
-#  to phase variation, mainly through the variation in the timing of the
+#
+#  Finally, a large prortion of the variation in the growth curve data is 
+#  due to phase variation, mainly through the variation in the timing of the
 #  pubertal growth spurt.  Registration therefore plays a major role and is
 #  especially illustrated here.
+#
 #  Most of the analyses are carried out on the Berkeley growth data, which
 #  have the advantage of being freely distributable, whereas as more recent
 #  and larger data bases require special permission from the agencies that
@@ -45,22 +48,25 @@
 #                           Berkeley Growth Data
 #  -----------------------------------------------------------------------
 
-#  Last modified 21 March 2006
-
-#  ------------------------  input the data  -----------------------
-
-ncasem <- 39
-ncasef <- 54
-nage   <- 31
+#  Last modified 2008.06.21;  previously modified 21 March 2006
+###
+###
+### 0.  Access the data (available in the 'fda' package)
+###
+###
 
 attach(growth)
-#age <- c( seq(1, 2, 0.25), seq(3, 8, 1), seq(8.5, 18, 0.5))
-# attribute of growth;  don't need to create 'age'
-#  when we attach growth.  
-rng <- c(1,18)
-agefine <- seq(1,18,length=101)
+(nage <- length(age))
+(ncasem <- ncol(hgtm))
+(ncasef <- ncol(hgtf))
 
-#  --------------  Smooth the data nonmonotonically  --------------
+(ageRng <- range(age))
+agefine <- seq(ageRng[1],ageRng[2],length=101)
+###
+###
+### 1.  Smooth the data (ignore monotonicity) --------------
+###
+###
 #  This smooth uses the usual smoothing methods to smooth the data,
 #  but is not guaranteed to produce a monotone fit.  This may not
 #  matter much for the estimate of the height function, but it can
@@ -71,6 +77,19 @@ agefine <- seq(1,18,length=101)
 #  -----------  Create fd objects   ----------------------------
 #  A B-spline basis with knots at age values and order 6 is used
 
+# A single call to smooth.basisPar would give us a cubic spline.  
+# However, to get a smooth image of acceleration,
+# we need a quintic spline (degree 5, order 6) 
+
+# .... 
+hgtmfd <- smooth.basisPar(age, hgtm, growfdPar)$fd
+
+
+
+
+
+
+
 knots  <- age
 norder <- 6
 nbasis <- length(knots) + norder - 2
@@ -144,8 +163,11 @@ for (i in children) {
          xlab="Years", ylab="", main="Acceleration")
     abline(h=0, lty=2)
 }
-
-#  -------  Compute monotone smooths of the data  -----------
+###
+###
+### 2.  Smooth the data monotonically  
+###
+###
 
 #  These analyses use a function written entirely in S-PLUS called
 #  smooth.monotone that fits the data with a function of the form
@@ -300,8 +322,11 @@ for (i in children) {
 }
 
 #  ---------------------------------------------------------------------
-#            Register the velocity curves for the girls
-#  ---------------------------------------------------------------------
+###
+###
+### 3.  Register the velocity curves for the girls
+###
+###
 
 nbasisw <- 15
 norder  <- 5
@@ -345,9 +370,11 @@ for (i in children) {
 }
 
 #  -----------------------------------------------------------------------
-#            Monotone smooth of short term growth data
-#  -----------------------------------------------------------------------
-
+###
+###
+### 4.  Monotone smooth of short term height measurements 
+###
+###
 #  ---------------- input the data  ----------------------------------
 
 temp <- scan("../data/onechild.txt",0)
